@@ -3,16 +3,6 @@ import re
 NAME_REGEX = re.compile(r"([A-Za-z0-9\_]+)")
 
 
-class AccessDeniedOrDoesNotExistException(Exception):
-    def __init__(self, message: str, object_name: str, object_type: str):
-        self.message = message
-        self.object_name = object_name
-        self.object_type = object_type
-
-    def __str__(self):
-        return self.message
-
-
 class MetricsLayerBase:
     def __init__(self, definition: dict = {}) -> None:
         self._definition = definition
@@ -24,7 +14,7 @@ class MetricsLayerBase:
         return f"<{self.__class__.__name__} name={self.name}>"
 
     def to_dict(self):
-        return self._definition
+        return {**self._definition}
 
     @staticmethod
     def valid_name(name: str):
